GR3 Reference
-------------

General Functions
^^^^^^^^^^^^^^^^^
.. autofunction:: gr3.init
.. autofunction:: gr3.terminate
.. autofunction:: gr3.getrenderpathstring
.. autofunction:: gr3.geterrorstring
.. autofunction:: gr3.setlogcallback

Scene Description Functions
^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. autofunction:: gr3.clear
.. autofunction:: gr3.cameralookat
.. autofunction:: gr3.setcameraprojectionparameters
.. autofunction:: gr3.setlightdirection
.. autofunction:: gr3.setbackgroundcolor
.. autofunction:: gr3.createmesh
.. autofunction:: gr3.createindexedmesh
.. autofunction:: gr3.createisosurfacemesh
.. TODO: autofunction:: gr3.setobjectid
.. TODO: above wrapper doesnt exist
.. autofunction:: gr3.drawmesh
.. autofunction:: gr3.deletemesh
.. autofunction:: gr3.drawconemesh
.. autofunction:: gr3.drawcylindermesh
.. autofunction:: gr3.drawspheremesh
.. autofunction:: gr3.createsurfacemesh
.. autofunction:: gr3.drawmesh_grlike
.. autofunction:: gr3.drawsurface
.. autofunction:: gr3.surface

Export and Drawing Functions
^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. autofunction:: gr3.getimage
.. autofunction:: gr3.drawimage
.. autofunction:: gr3.export
.. autofunction:: gr3.setquality

Interaction Functions
^^^^^^^^^^^^^^^^^^^^^

.. TODO: autofunction:: gr3.selectid
.. TODO: above wrapper doesnt exist
